EnteredCriticalSection

Struct EnteredCriticalSection 

pub struct EnteredCriticalSection<'a, T>(/* private fields */);
Available on Py_3_14 and non-Py_LIMITED_API and crate feature tls only.
Allows access to data protected by a PyMutex in a critical section

Used with the with_critical_section_mutex and with_critical_section_mutex2 functions. See the documentation of those functions for more details.

Implementations



impl<T> EnteredCriticalSection<'_, T>

pub unsafe fn get_mut(&mut self) -> &mut T

Get a mutable reference to the data wrapped by a PyMutex

Safety

The caller must ensure the closure cannot implicitly release the critical section.

If a multithreaded program calls back into the Python interpreter in a manner that would cause the critical section to be released, the PyMutex will be unlocked and the resource protected by the PyMutex may be read from or modified by another thread while the critical section is suspended. Concurrent modifications are impossible, but races are possible and the state of the protected resource may change in possibly surprising ways after calls into the interpreter.

pub unsafe fn get(&self) -> &T

Get a immutable reference to the value wrapped by a PyMutex

Safety

The caller must ensure the critical section is not released while the reference is alive. If a multithreaded program calls back into the Python interpreter in a manner that would cause the critical section to be released, the PyMutex will be unlocked and the resource protected by the PyMutex may be read from or modified by another thread while the critical section is suspended and the thread that owns the reference is blocked. Concurrent modifications are impossible, but races are possible and the state of an object may change “underneath” a suspended thread in possibly surprising ways. Note that many operations on Python objects may call back into the interpreter in a blocking manner because many C API calls can trigger the execution of arbitrary Python code.